/*  zomg/uuid, a zsh module for generating UUIDs
    Copyright (C) 2007  Clint Adams

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "config.h"
#include <stdio.h>

#ifdef HAVE_UUID_UUID_H
# include <uuid/uuid.h>
#else
# error "Install uuid-dev"
#endif

#include "uuid.mdh"
#include "uuid.pro"

static char *nam="zomg/uuid";

/**/
static int
bin_zuuid(char *nam, char **args, Options ops, UNUSED(int func))
{
    uuid_t u;
    char uuid[37];

    uuid_generate(u);
    uuid_unparse(u, uuid);
    printf("%s\n", uuid);

    return 0;
}

/*
 * boot_ is executed when the module is loaded.
 */

static struct builtin bintab[] = {
    BUILTIN("zuuid", 0, bin_zuuid, 0, 0, 0, NULL, NULL),
};

/**/
int
setup_(UNUSED(Module m))
{
    return 0;
}

/**/
int
boot_(Module m)
{
    return !(addbuiltins(m->nam, bintab, sizeof(bintab)/sizeof(*bintab)));
}

/**/
int
cleanup_(Module m)
{
    deletebuiltins(m->nam, bintab, sizeof(bintab)/sizeof(*bintab));
    return 0;
}

/**/
int
finish_(UNUSED(Module m))
{
    return 0;
}
